/* Copyright (C) 2003 MySQL AB

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */

#ifndef myx_admin_library_h
#define myx_admin_library_h

#if defined(__WIN__) || defined(_WIN32) || defined(_WIN64)
#include <winsock2.h>
#endif

#include <mysql.h>
#include <mysql_version.h>

#include <myx_public_interface.h>
#include <myx_admin_public_interface.h>

#include <myx_library.h>

//extern enum myx_lib_error error_code;

/*
 * Enums
 */


/*
 * Structs
 */


/*
 * Functions
 */
MYX_GUI_DESCRIPTION* myx_init_gui_description_with_default_values(MYX_GUI_DESCRIPTION *desc);
MYX_GUI_DESCRIPTION* myx_process_mysql_cnf_file(MYX_GUI_DESCRIPTION *desc, const char *ini_filepath, const char *group, MYX_ADMIN_LIB_ERROR *error_code);

#endif

